<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
        <source>URI and driver do not match.</source>
        <translation>URI 與驅動程式不符。</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>請先安裝 hplip 後再重新啟動 App 以再次安裝驅動。</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>請選取 hplip 驅動程式後重試。</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
        <source>URI can&apos;t be empty</source>
        <translation>URI 不能空白</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
        <source> not found</source>
        <translation>未找到</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>檢查印表機設置</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>檢查印表機設置中...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>獲取印表機屬性失敗。錯誤原因：</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1未啟用</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>不接收任務</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>印表機設置正常</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>檢查印表機連接狀態</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>檢查印表機連接狀態中...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>連接印表機失敗，錯誤原因：%1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation>未連接，URI：</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 目錄不存在</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>連接印表機失敗</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>印表機連接狀態正常</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>檢查CUPS服務是否開啟</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>檢查CUPS服務中...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>CUPS服務異常</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>CUPS服務正常</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>檢查驅動文件中...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>PPD文件 %1 未找到</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>驅動文件已損壞</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>驅動Filter %1 未找到</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 未安裝，列印異常</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>驅動文件完好</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>檢查驅動</translation>
    </message>
</context>
<context>
    <name>DPrinterSupplyShowDlg</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="166"/>
        <source>Low level</source>
        <translation>餘量不足</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="196"/>
        <source>Unknown</source>
        <translation>餘量未知</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="261"/>
        <source>Ink/Toner Status</source>
        <translation>耗材餘量</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="268"/>
        <source>Unknown amount</source>
        <translation>油墨量未知</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="276"/>
        <source>Unable to get the remaining amount</source>
        <translation>未獲取到油墨量資料</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="312"/>
        <source>The amounts are estimated, last updated at %1</source>
        <translation>所有餘量為估計值 ，更新時間為今天%1</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="325"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>DPrinterTanslator</name>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="33"/>
        <source>Color</source>
        <translation>彩色</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="34"/>
        <location filename="../util/dprintertanslator.cpp" line="35"/>
        <source>Grayscale</source>
        <translation>灰度</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="38"/>
        <location filename="../util/dprintertanslator.cpp" line="69"/>
        <location filename="../util/dprintertanslator.cpp" line="86"/>
        <location filename="../util/dprintertanslator.cpp" line="107"/>
        <location filename="../util/dprintertanslator.cpp" line="126"/>
        <location filename="../util/dprintertanslator.cpp" line="135"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="39"/>
        <location filename="../util/dprintertanslator.cpp" line="49"/>
        <source>Draft</source>
        <translation>草稿</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="40"/>
        <location filename="../util/dprintertanslator.cpp" line="120"/>
        <source>Normal</source>
        <translation>從前向後</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="43"/>
        <location filename="../util/dprintertanslator.cpp" line="44"/>
        <location filename="../util/dprintertanslator.cpp" line="47"/>
        <source>Print Quality</source>
        <translation>列印質量</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="48"/>
        <location filename="../util/dprintertanslator.cpp" line="60"/>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="52"/>
        <location filename="../util/dprintertanslator.cpp" line="53"/>
        <location filename="../util/dprintertanslator.cpp" line="54"/>
        <source>Paper Source</source>
        <translation>紙張來源</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="55"/>
        <location filename="../util/dprintertanslator.cpp" line="56"/>
        <source>Auto-Select</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="57"/>
        <location filename="../util/dprintertanslator.cpp" line="58"/>
        <source>Manual Feeder</source>
        <translation>多功能托盤</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="59"/>
        <location filename="../util/dprintertanslator.cpp" line="73"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="61"/>
        <source>Drawer 1</source>
        <translation>紙盒1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="62"/>
        <source>Drawer 2</source>
        <translation>紙盒2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="63"/>
        <source>Drawer 3</source>
        <translation>紙盒3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="64"/>
        <source>Drawer 4</source>
        <translation>紙盒4</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="65"/>
        <source>Drawer 5</source>
        <translation>紙盒5</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="66"/>
        <source>Envelope Feeder</source>
        <translation>信封輸送器</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="67"/>
        <source>Tray1</source>
        <translation>托盤1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="68"/>
        <source>Unknown</source>
        <translation>未定義的</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="72"/>
        <source>MediaType</source>
        <translation>紙張類型</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="74"/>
        <source>Plain Paper</source>
        <translation>普通紙</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="75"/>
        <source>Recycled Paper</source>
        <translation>再生紙</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="76"/>
        <source>Color Paper</source>
        <translation>彩色紙</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="77"/>
        <source>Bond Paper</source>
        <translation>銅版紙</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="78"/>
        <source>Heavy Paper 1</source>
        <translation>重磅紙1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="79"/>
        <source>Heavy Paper 2</source>
        <translation>重磅紙2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="80"/>
        <source>Heavy Paper 3</source>
        <translation>重磅紙3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="81"/>
        <location filename="../util/dprintertanslator.cpp" line="82"/>
        <source>OHP</source>
        <translation>膠片</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="83"/>
        <source>Labels</source>
        <translation>標籤</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="84"/>
        <source>Envelope</source>
        <translation>信封</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="85"/>
        <source>Photo Paper</source>
        <translation>照片紙</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="89"/>
        <location filename="../util/dprintertanslator.cpp" line="90"/>
        <location filename="../util/dprintertanslator.cpp" line="91"/>
        <source>PageSize</source>
        <translation>紙張大小</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="92"/>
        <source>Custom</source>
        <translation>自訂</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="95"/>
        <location filename="../util/dprintertanslator.cpp" line="96"/>
        <location filename="../util/dprintertanslator.cpp" line="97"/>
        <source>Duplex</source>
        <translation>雙面列印</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="98"/>
        <source>DuplexTumble</source>
        <translation>雙面，短邊</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="99"/>
        <source>DuplexNoTumble</source>
        <translation>雙面，長邊</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="100"/>
        <source>ON (Long-edged Binding)</source>
        <translation>雙面，長邊</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="101"/>
        <source>ON (Short-edged Binding)</source>
        <translation>雙面，短邊</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="102"/>
        <location filename="../util/dprintertanslator.cpp" line="103"/>
        <source>OFF</source>
        <translation>單面</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="106"/>
        <location filename="../util/dprintertanslator.cpp" line="110"/>
        <source>Binding Edge</source>
        <translation>裝訂邊</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="108"/>
        <source>Left</source>
        <translation>左側</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="109"/>
        <source>Top</source>
        <translation>頂部</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="113"/>
        <source>Portrait (no rotation)</source>
        <translation>縱向（無旋轉）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="114"/>
        <source>Landscape (90 degrees)</source>
        <translation>橫向（90 度）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="115"/>
        <source>Reverse landscape (270 degrees)</source>
        <translation>反橫向（270 度）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="116"/>
        <source>Reverse portrait (180 degrees)</source>
        <translation>反縱向（180 度）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="117"/>
        <source>Auto Rotation</source>
        <translation>自動旋轉</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="121"/>
        <source>Reverse</source>
        <translation>從後往前</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="124"/>
        <location filename="../util/dprintertanslator.cpp" line="125"/>
        <source>Staple Location</source>
        <translation>裝訂位置</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="127"/>
        <source>Bind</source>
        <translation>裝訂</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="128"/>
        <source>Bind (none)</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="129"/>
        <source>Bind (bottom)</source>
        <translation>裝訂（下）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="130"/>
        <source>Bind (left)</source>
        <translation>裝訂（左）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="131"/>
        <source>Bind (right)</source>
        <translation>裝訂（右）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="132"/>
        <source>Bind (top)</source>
        <translation>裝訂（上）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="136"/>
        <location filename="../util/dprintertanslator.cpp" line="137"/>
        <source>Resolution</source>
        <translation>解析度</translation>
    </message>
</context>
<context>
    <name>DPrintersShowWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="91"/>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="99"/>
        <source>Printers</source>
        <translation>印表機設備</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="104"/>
        <source>Add printer</source>
        <translation>添加印表機</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="107"/>
        <source>Delete printer</source>
        <translation>刪除印表機</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="142"/>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="143"/>
        <source>Shared</source>
        <translation>共享</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="146"/>
        <source>Enabled</source>
        <translation>啟用</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="149"/>
        <source>Accept jobs</source>
        <translation>接受任務</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="153"/>
        <source>Set as default</source>
        <translation>設為默認</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="166"/>
        <source>No Printers</source>
        <translation>無列印設備</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="193"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="198"/>
        <source>Model:</source>
        <translation>型號：</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="201"/>
        <source>Status:</source>
        <translation>狀態：</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="237"/>
        <source>Properties</source>
        <translation>屬性</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="665"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="667"/>
        <source>Print Queue</source>
        <translation>列印隊列</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="670"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="672"/>
        <source>Print Test Page</source>
        <translation>列印測試頁</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="274"/>
        <source>Supplies</source>
        <translation>耗材</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="310"/>
        <source>No printer configured</source>
        <translation>未配置印表機</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="316"/>
        <source>Click + to add printers</source>
        <translation>請點擊添加按鈕（+），添加印表機</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="365"/>
        <source>As print jobs are in process, you cannot rename the printer now, please try later</source>
        <translation>有正在進行的列印任務，無法重命名，請稍後再試</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="369"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="428"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="786"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="425"/>
        <source>CUPS server is not running, and can’t manage printers.</source>
        <translation>CUPS伺服器未運行，不能管理印表機。</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="692"/>
        <source>Idle</source>
        <translation>空閒</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="694"/>
        <source>Printing</source>
        <translation>列印中</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="696"/>
        <source>Disabled</source>
        <translation>已停用</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="744"/>
        <source>Are you sure you want to delete the printer &quot;%1&quot; ?</source>
        <translation>您確定要刪除印表機“%1”嗎？</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="750"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="782"/>
        <source>The name already exists</source>
        <translation>此名稱已存在</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="801"/>
        <source>You will not be able to reprint the completed jobs if continue. Are you sure you want to rename the printer?</source>
        <translation>重命名會導致已完成的任務不能重複列印，您確定要重命名嗎？</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="806"/>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="865"/>
        <source>The driver is damaged, please install it again.</source>
        <translation>驅動文件已損壞，請重新安裝驅動。</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="868"/>
        <source>Install Driver</source>
        <translation>安裝驅動</translation>
    </message>
</context>
<context>
    <name>DPropertySetDlg</name>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="261"/>
        <source>Print Properties</source>
        <translation>列印屬性</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="262"/>
        <source>Driver</source>
        <translation>驅動</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="263"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="264"/>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="265"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="266"/>
        <source>Color Mode</source>
        <translation>顏色</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="267"/>
        <source>Orientation</source>
        <translation>方向</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="268"/>
        <source>Page Order</source>
        <translation>列印順序</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="703"/>
        <source>Options conflict!</source>
        <translation>選項衝突!</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="706"/>
        <source>Please resolve the conflict first, and then save the changes.</source>
        <translation>只有在衝突解決後才能應用所做修改!</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="725"/>
        <source>Conflict:</source>
        <translation>衝突項：</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="736"/>
        <location filename="../ui/dpropertysetdlg.cpp" line="1234"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="1233"/>
        <source>Invalid URI</source>
        <translation>URI格式不正確</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
        <source>EveryWhere driver</source>
        <translation>EveryWhere 無驅方案</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>查找驅動解決方案：%1失敗，錯誤碼：%2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
        <source>The solution is invalid</source>
        <translation>伺服器的驅動數據不對</translation>
    </message>
</context>
<context>
    <name>InstallDriverWindow</name>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="103"/>
        <location filename="../ui/installdriverwindow.cpp" line="107"/>
        <source>Select a driver from</source>
        <translation>選擇驅動來源</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="113"/>
        <location filename="../ui/installdriverwindow.cpp" line="116"/>
        <source>Local driver</source>
        <translation>本機驅動</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="118"/>
        <location filename="../ui/installdriverwindow.cpp" line="121"/>
        <source>Local PPD file</source>
        <translation>本機PPD文件</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="123"/>
        <location filename="../ui/installdriverwindow.cpp" line="126"/>
        <source>Search for a driver</source>
        <translation>搜索印表機驅動</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="146"/>
        <location filename="../ui/installdriverwindow.cpp" line="464"/>
        <source>Choose a local driver</source>
        <translation>選擇本機驅動</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="150"/>
        <source>Vendor</source>
        <translation>廠商</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="164"/>
        <source>Model</source>
        <translation>型號</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="177"/>
        <location filename="../ui/installdriverwindow.cpp" line="259"/>
        <source>Driver</source>
        <translation>驅動</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="242"/>
        <source>Vendor and Model</source>
        <translation>廠商和型號</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="244"/>
        <source>Enter a complete vendor and model (Only letters, numbers and whitespaces)</source>
        <translation>請輸入完整的廠商和型號（僅限字母、數字及空格）</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="247"/>
        <source>Search</source>
        <comment>button</comment>
        <translation>搜 索</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="296"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>安裝驅動</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="446"/>
        <location filename="../ui/installdriverwindow.cpp" line="556"/>
        <source>Reselect</source>
        <translation>重新選擇</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="472"/>
        <location filename="../ui/installdriverwindow.cpp" line="553"/>
        <source>Select a PPD file</source>
        <translation>選擇PPD文件</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="481"/>
        <source>Search for printer driver</source>
        <translation>搜索印表機驅動</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="535"/>
        <source>(recommended)</source>
        <translation>（推薦）</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="707"/>
        <source> (recommended)</source>
        <translation>（推薦）</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
        <source>is invalid</source>
        <translation>無法安裝</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>通過dbus安裝驅動失敗</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
        <source>Failed to install %1</source>
        <translation>安裝%1失敗</translation>
    </message>
</context>
<context>
    <name>InstallPrinterWindow</name>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="87"/>
        <location filename="../ui/installprinterwindow.cpp" line="163"/>
        <source>Installing driver...</source>
        <translation>正在安裝驅動...</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="97"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="100"/>
        <location filename="../ui/installprinterwindow.cpp" line="186"/>
        <location filename="../ui/installprinterwindow.cpp" line="203"/>
        <source>View Printer</source>
        <comment>button</comment>
        <translation>查看印表機</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="102"/>
        <location filename="../ui/installprinterwindow.cpp" line="188"/>
        <location filename="../ui/installprinterwindow.cpp" line="205"/>
        <source>Print Test Page</source>
        <comment>button</comment>
        <translation>列印測試頁</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="175"/>
        <source>Successfully installed </source>
        <translation>安裝成功</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="181"/>
        <location filename="../ui/installprinterwindow.cpp" line="199"/>
        <source>You have successfully added the printer. Print a test page to check if it works properly.</source>
        <translation>測試頁是否列印成功?</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="193"/>
        <source>Printing test page...</source>
        <translation>添加印表機成功。請列印測試頁測試印表機是否能夠正常列印。</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="210"/>
        <source>Did you print the test page successfully?</source>
        <translation>如果列印成功，請選擇是；如果列印失敗，請選擇否</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="216"/>
        <source>If succeeded, click Yes; if failed, click No</source>
        <translation>如果列印成功，請選擇是；如果列印失敗，請選擇否</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="219"/>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="221"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="226"/>
        <location filename="../ui/installprinterwindow.cpp" line="246"/>
        <source>Print failed</source>
        <translation>列印失敗</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="232"/>
        <source>Click Reinstall to install the printer driver again, or click Troubleshoot to start troubleshooting.</source>
        <translation>選擇重新安裝將再次安裝印表機驅動，選擇故障排查將進行印表機故障診斷</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="235"/>
        <location filename="../ui/installprinterwindow.cpp" line="256"/>
        <source>Reinstall</source>
        <comment>button</comment>
        <translation>重新安裝</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="237"/>
        <location filename="../ui/installprinterwindow.cpp" line="258"/>
        <source>Troubleshoot</source>
        <comment>button</comment>
        <translation>故障排查</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="244"/>
        <source>Installation failed</source>
        <translation>安裝失敗</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="252"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="253"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="254"/>
        <source>Pause</source>
        <translation>暫停列印</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="255"/>
        <source>Resume</source>
        <translation>恢復列印</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="256"/>
        <source>Print first</source>
        <translation>優先列印</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="257"/>
        <source>Reprint</source>
        <translation>重新列印</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="259"/>
        <source>No print jobs</source>
        <translation>暫無列印任務</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="405"/>
        <source>Are you sure you want to delete this job?</source>
        <translation>您確定要刪除此列印任務嗎？</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="411"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="412"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>刪 除</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>未找到</translation>
    </message>
</context>
<context>
    <name>JobManagerWindow</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1099"/>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1105"/>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1106"/>
        <source>Print Queue</source>
        <translation>列印隊列</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1107"/>
        <source>Completed</source>
        <translation>已完成</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1176"/>
        <source> failed</source>
        <translation>失敗</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1197"/>
        <source>%1 jobs</source>
        <translation>%1項任務</translation>
    </message>
</context>
<context>
    <name>JobsDataModel</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="713"/>
        <source>Job</source>
        <translation>任務</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="715"/>
        <source>User</source>
        <translation>用戶</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="717"/>
        <source>Document</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="719"/>
        <source>Printer</source>
        <translation>印表機</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="721"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="723"/>
        <source>Time submitted</source>
        <translation>提交時間</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="725"/>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="727"/>
        <source>Action</source>
        <translation>操作</translation>
    </message>
</context>
<context>
    <name>PermissionsWindow</name>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="48"/>
        <source>Connect to %1 to find a printer</source>
        <translation>查找印表機需要登錄%1</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="74"/>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="76"/>
        <source>Group</source>
        <translation>群組</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="78"/>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="92"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="93"/>
        <source>Connect</source>
        <translation>連接</translation>
    </message>
</context>
<context>
    <name>PrinterApplication</name>
    <message>
        <location filename="../ui/printerapplication.cpp" line="104"/>
        <source>Print Manager</source>
        <translation>列印管理器</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="105"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>列印管理器是一款基於CUPS的印表機管理工具，支持印表機管理，列印任務管理等。</translation>
    </message>
</context>
<context>
    <name>PrinterSearchWindow</name>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="88"/>
        <location filename="../ui/printersearchwindow.cpp" line="91"/>
        <source>Discover printer</source>
        <translation>自動查找</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="94"/>
        <location filename="../ui/printersearchwindow.cpp" line="97"/>
        <source>Find printer</source>
        <translation>手動查找</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="99"/>
        <location filename="../ui/printersearchwindow.cpp" line="102"/>
        <source>Enter URI</source>
        <translation>URI查找</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="125"/>
        <source>Select a printer</source>
        <translation>選擇印表機</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="132"/>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="155"/>
        <location filename="../ui/printersearchwindow.cpp" line="268"/>
        <source>No printers found</source>
        <translation>未找到印表機</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="202"/>
        <source>Install Driver</source>
        <translation>安裝驅動</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="233"/>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="236"/>
        <source>Enter an address</source>
        <translation>請輸入地址</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="238"/>
        <source>Find</source>
        <comment>button</comment>
        <translation>查 找</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="346"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="351"/>
        <source>Enter device URI</source>
        <translation>請輸入URI</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="376"/>
        <source>Examples:</source>
        <translation>例如：</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="698"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="784"/>
        <source> (recommended)</source>
        <translation>（推薦）</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="794"/>
        <source>The driver was found</source>
        <translation>已匹配到該驅動</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="795"/>
        <source>Connect to the network and try again</source>
        <translation>請連網後重試</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="797"/>
        <source>Cannot find the driver</source>
        <translation>未匹配到該驅動</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="798"/>
        <source>Please try to install it manually or search its official website</source>
        <translation>可嘗試手動安裝或跳轉官網查詢</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="808"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>檢查測試頁列印情況</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>添加印表機成功。請列印測試頁測試印表機是否能夠正常列印。</translation>
    </message>
</context>
<context>
    <name>PrinterTestPageDialog</name>
    <message>
        <location filename="../ui/printertestpagedialog.cpp" line="61"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="226"/>
        <source>Black</source>
        <translation>黑色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="227"/>
        <source>Blue</source>
        <translation>藍色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="228"/>
        <source>Brown</source>
        <translation>褐色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="229"/>
        <source>Cyan</source>
        <translation>青色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="230"/>
        <source>Dark-gray</source>
        <translation>深灰色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="231"/>
        <source>Dark gray</source>
        <translation>深灰色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="232"/>
        <source>Dark-yellow</source>
        <translation>深黃色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="233"/>
        <source>Dark yellow</source>
        <translation>深黃色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="234"/>
        <source>Gold</source>
        <translation>金色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="235"/>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="236"/>
        <source>Green</source>
        <translation>綠色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="237"/>
        <source>Light-black</source>
        <translation>淺黑色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="238"/>
        <source>Light black</source>
        <translation>淺黑色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="239"/>
        <source>Light-cyan</source>
        <translation>淺青色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="240"/>
        <source>Light cyan</source>
        <translation>淺青色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="241"/>
        <source>Light-gray</source>
        <translation>淺灰色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="242"/>
        <source>Light gray</source>
        <translation>淺灰色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="243"/>
        <source>Light-magenta</source>
        <translation>淺洋紅色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="244"/>
        <source>Light magenta</source>
        <translation>淺洋紅色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="245"/>
        <source>Magenta</source>
        <translation>洋紅色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="246"/>
        <source>Orange</source>
        <translation>橙色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="247"/>
        <source>Red</source>
        <translation>紅色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="248"/>
        <source>Silver</source>
        <translation>銀色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="249"/>
        <source>White</source>
        <translation>白色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="250"/>
        <source>Yellow</source>
        <translation>黃色</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="251"/>
        <source>Waste</source>
        <translation>廢粉</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="108"/>
        <source>1 min ago</source>
        <translation>1分鐘以前</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="111"/>
        <source>%1 mins ago</source>
        <translation>%1分鐘以前</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="115"/>
        <source>1 hr ago</source>
        <translation>1小時以前</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="117"/>
        <source>%1 hrs ago</source>
        <translation>%1小時以前</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="122"/>
        <source>Yesterday</source>
        <translation>昨天</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="124"/>
        <source>%1 days ago</source>
        <translation>%1天以前</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="113"/>
        <source>Direct-attached Device</source>
        <translation>直連裝置</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="114"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="616"/>
        <source>(use %1 protocol)</source>
        <translation>（使用%1協議）</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="26"/>
        <source>Select a driver</source>
        <translation>手動選擇驅動方案</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="32"/>
        <source>Driver</source>
        <translation>驅動</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="33"/>
        <source>Next</source>
        <comment>button</comment>
        <translation>下一步</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="34"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>安裝驅動</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="36"/>
        <source>Drag a PPD file here 
 or</source>
        <translation>請拖放PPD文件到此處
或</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="37"/>
        <source>Select a PPD file</source>
        <comment>button</comment>
        <translation>選擇PPD文件</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="39"/>
        <source>Troubleshoot</source>
        <translation>故障排查</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="40"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="43"/>
        <source>For more drivers, please refer to our official website: </source>
        <translation>更多驅動詳見官網：</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="201"/>
        <source>Idle</source>
        <translation>空閒</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="204"/>
        <source>Printing</source>
        <translation>列印中</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="207"/>
        <source>Disabled</source>
        <translation>已停用</translation>
    </message>
    <message>
        <location filename="../util/dprinter.cpp" line="285"/>
        <source>(recommended)</source>
        <translation>（推薦）</translation>
    </message>
    <message>
        <location filename="../ui/dprinterpropertytemplate.h" line="33"/>
        <source>Preferences</source>
        <translation>列印偏好設定</translation>
    </message>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
        <translation>%1無法解析，請聯絡管理員，或前往屬性-URI手動輸入印表機IP</translation>
    </message>
</context>
<context>
    <name>RenamePrinterWindow</name>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="84"/>
        <source>Rename Printer</source>
        <translation>重命名印表機</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="91"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="93"/>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="95"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="106"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="107"/>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>ServerSettingsWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="92"/>
        <source>Basic Server Settings</source>
        <translation>基本伺服器設置</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="101"/>
        <source>Publish shared printers connected to this system</source>
        <translation>發布連接到這個系統的共享印表機</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="103"/>
        <source>Allow printing from the Internet</source>
        <translation>允許從網際網路列印</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="105"/>
        <source>Allow remote administration</source>
        <translation>允許遠程管理</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="107"/>
        <source>Save debugging information for troubleshooting</source>
        <translation>保留除錯訊息用於故障排除</translation>
    </message>
</context>
<context>
    <name>TroubleShootDialog</name>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="118"/>
        <source>Troubleshoot: </source>
        <translation>故障排查：</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="145"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="178"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
</TS>